==> order-center-api-2.9.0-CLOUD-20240202.024418-11-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqPayConfBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocCreateOrderServiceReqPayConfBo
 * 说明:
 * 时间:2022/2/23 18:03
 * 作者:田桂银
 */
@Data
public class UocCreateOrderServiceReqPayConfBo implements Serializable {

    private static final long serialVersionUID = -460642090735099897L;


    @DocField(value = "结算模式 2:撮合 1:贸易",required = true)
    private Integer modelSettle;

    @DocField(value = "付款方式 0 预付款按比例支付,1 按协议约束支付,2 按账期支付",required = true)
    private Integer payType;

    @DocField(value = "预付款(比例)")
    private BigDecimal prePaySup;

    @DocField(value = "到货款(比例)")
    private BigDecimal verPaySup;

    @DocField(value = "验收款(比例)")
    private BigDecimal pilPaySup;

    @DocField(value = "质保金(比例)")
    private BigDecimal quaPaySup;

    @DocField(value = "账期天数")
    private Integer paymentDays;

    @DocField(value = "指定账期日")
    private Integer payAccountDay;

    @DocField(value = "使用类型：1：采购方；2：平台方")
    private Integer userType;

    @DocField(value = "账期支付结算规则 1:指定账期日 2:账期起算特定业务节点+账期天数")
    private Integer payRule;

    @DocField(value = "违约金额比例")
    private BigDecimal payBreakScale;

    @DocField(value = "账期日结算订单规则 1:签收发票开始 2:订单验收 3:订单到货")
    private Integer payAccountDayRule;

    @DocField(value = "账期起算特定业务节点 1:签收发票开始计算 2:订单验收开始计算 3:订单到货开始计算")
    private Integer payNodeRule;

    @DocField(value = "合同ID")
    private String modelContractId;

    @DocField(value = "备注")
    private String remark;


}

==> order-center-api-3.1.1.0-CLOUD-20230419.132612-69-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocCreateOrderServiceReqPayConfBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题:UocCreateOrderServiceReqPayConfBo
 * 说明:
 * 时间:2022/2/23 18:03
 * 作者:田桂银
 */
@Data
public class UocCreateOrderServiceReqPayConfBo implements Serializable {

    private static final long serialVersionUID = -460642090735099897L;


    /**
     * 结算模式 2:撮合 1:贸易
     */
    private Integer modelSettle;

    /**
     * 付款方式 0 预付款按比例支付,1 按协议约束支付,2 按账期支付
     */
    private Integer payType;

    /**
     * 预付款(比例)
     */
    private BigDecimal prePaySup;

    /**
     * 到货款(比例)
     */
    private BigDecimal verPaySup;

    /**
     * 验收款(比例)
     */
    private BigDecimal pilPaySup;

    /**
     * 质保金(比例)
     */
    private BigDecimal quaPaySup;

    /**
     * 账期天数
     */
    private Integer paymentDays;

    /**
     * 指定账期日
     */
    private Integer payAccountDay;

    /**
     * 使用类型：1：采购方；2：平台方
     */
    private Integer userType;

    /**
     * 账期支付结算规则 1:指定账期日 2:账期起算特定业务节点+账期天数
     */
    private Integer payRule;

    /**
     * 违约金额比例
     */
    private BigDecimal payBreakScale;

    /**
     * 账期日结算订单规则 1:签收发票开始 2:订单验收 3:订单到货
     */
    private Integer payAccountDayRule;

    /**
     * 账期起算特定业务节点 1:签收发票开始计算 2:订单验收开始计算 3:订单到货开始计算
     */
    private Integer payNodeRule;

    /**
     * 合同ID
     */
    private String modelContractId;

    /**
     * 备注
     */
    private String remark;


}
